@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -152,6 +152,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "CN", "K\u00edna" },
             { "CO", "Kolumbia" },
             { "CP", "Clipperton-sziget" },
+            { "CQ", "Sark" },
             { "CR", "Costa Rica" },
             { "CU", "Kuba" },
             { "CV", "Z\u00f6ld-foki K\u00f6zt\u00e1rsas\u00e1g" },
@@ -561,6 +562,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "ang", "\u00f3angol" },
             { "ann", "obolo" },
             { "anp", "angika" },
+            { "apc", "levantei arab" },
             { "arc", "ar\u00e1mi" },
             { "arn", "mapucse" },
             { "arp", "arapaho" },
@@ -579,6 +581,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "bem", "bemba" },
             { "bez", "bena" },
             { "bfd", "bafut" },
+            { "bgc", "haryanvi" },
             { "bgn", "nyugati beludzs" },
             { "bho", "bodzspuri" },
             { "bik", "bikol" },
@@ -732,6 +735,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "lij", "ligur" },
             { "lil", "lillooet" },
             { "lkt", "lakota" },
+            { "lmo", "lombard" },
             { "lol", "mong\u00f3" },
             { "lou", "louisianai kreol" },
             { "loz", "lozi" },
@@ -799,7 +803,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "ojw", "nyugati odzsibva" },
             { "oka", "okanagan" },
             { "osa", "osage" },
-            { "ota", "ottom\u00e1n t\u00f6r\u00f6k" },
+            { "ota", "oszm\u00e1n-t\u00f6r\u00f6k" },
             { "pag", "pangaszinan" },
             { "pal", "pahlavi" },
             { "pam", "pampangan" },
@@ -859,6 +863,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "swb", "comorei" },
             { "syc", "klasszikus sz\u00edr" },
             { "syr", "sz\u00edr" },
+            { "szl", "szil\u00e9ziai" },
             { "tce", "d\u00e9li tutchone" },
             { "tem", "temne" },
             { "teo", "tesz\u00f3" },
@@ -888,6 +893,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "umb", "umbundu" },
             { "und", "ismeretlen nyelv" },
             { "vai", "vai" },
+            { "vec", "velencei" },
             { "vot", "votj\u00e1k" },
             { "vun", "vunjo" },
             { "wae", "walser" },
@@ -912,6 +918,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "zxx", "nincs nyelv\u00e9szeti tartalom" },
             { "zza", "zaza" },
             { "Adlm", "Adlam" },
+            { "Aghb", "Kauk\u00e1zusi albaniai" },
             { "Arab", "Arab" },
             { "Aran", "Nasztalik" },
             { "Armi", "Birodalmi ar\u00e1mi" },
@@ -932,6 +939,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "Cham", "Cs\u00e1m" },
             { "Cher", "Cseroki" },
             { "Copt", "Kopt" },
+            { "Cpmn", "Ciprusi-min\u00f3szi" },
             { "Cprt", "Ciprusi" },
             { "Cyrl", "Cirill" },
             { "Cyrs", "\u00d3egyh\u00e1zi szl\u00e1v cirill" },
@@ -956,6 +964,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "Hant", metaValue_Hant },
             { "Hebr", "H\u00e9ber" },
             { "Hira", "Hiragana" },
+            { "Hluw", "Anat\u00f3liai hieroglif\u00e1k" },
             { "Hmng", "Pahawh hmong" },
             { "Hrkt", "Katakana vagy hiragana" },
             { "Hung", "\u00d3magyar" },
@@ -991,6 +1000,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "Moon", "Moon" },
             { "Mtei", "Meitei mayek" },
             { "Mymr", "Burmai" },
+            { "Nbat", "Nabateus" },
             { "Nkoo", "N\u2019ko" },
             { "Ogam", "Ogham" },
             { "Olck", "Ol chiki" },
@@ -1098,6 +1108,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "%%SAAHO", "Saho" },
             { "%%SOLBA", "Stolvizza/Solbica t\u00e1jsz\u00f3l\u00e1s" },
             { "%%UCCOR", "Egyes\u00edtett helyes\u00edr\u00e1s" },
+            { "hi_Latn", "hindi (latin)" },
             { "zh_Hans", "egyszer\u0171s\u00edtett k\u00ednai" },
             { "zh_Hant", "hagyom\u00e1nyos k\u00ednai" },
             { "%%FONIPA", "IPA fonetika" },
@@ -1196,7 +1207,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "type.ms.metric", "M\u00e9terrendszer" },
             { "type.nu.native", "Nat\u00edv sz\u00e1mjegyek" },
             { "type.ca.chinese", "K\u00ednai napt\u00e1r" },
-            { "type.ca.islamic", "Iszl\u00e1m napt\u00e1r" },
+            { "type.ca.islamic", "Hidzsra napt\u00e1r" },
             { "type.ca.iso8601", "ISO-8601 napt\u00e1r" },
             { "type.ca.persian", "Perzsa napt\u00e1r" },
             { "type.cf.account", "K\u00f6nyvel\u00e9si p\u00e9nznemform\u00e1tum" },
@@ -1216,7 +1227,6 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "type.ca.japanese", "Jap\u00e1n napt\u00e1r" },
             { "type.cf.standard", "Norm\u00e1l p\u00e9nznemform\u00e1tum" },
             { "type.co.phonetic", "Fonetikus rendez\u00e9si sorrend" },
-            { "type.co.reformed", "\u00c1talak\u00edtott rendez\u00e9si elv" },
             { "type.co.searchjl", "Keres\u00e9s hangul kezd\u0151 m\u00e1ssalhangz\u00f3 szerint" },
             { "type.co.standard", "Norm\u00e1l rendez\u00e9si sorrend" },
             { "type.ms.uksystem", "Angolsz\u00e1sz m\u00e9rt\u00e9kegys\u00e9grendszer" },
@@ -1229,8 +1239,8 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "type.co.dictionary", "Sz\u00f3t\u00e1ri rendez\u00e9si sorrend" },
             { "type.co.traditional", metaValue_Hant },
             { "type.nu.traditional", "Hagyom\u00e1nyos sz\u00e1mok" },
-            { "type.ca.islamic-civil", "Iszl\u00e1m civil napt\u00e1r" },
-            { "type.ca.islamic-umalqura", "Iszl\u00e1m Umm al-Qura napt\u00e1r" },
+            { "type.ca.islamic-civil", "Hidzsra napt\u00e1r (t\u00e1bl\u00e1zatos, polg\u00e1ri)" },
+            { "type.ca.islamic-umalqura", "Hidzsra napt\u00e1r (Umm al-Qura)" },
             { "type.ca.ethiopic-amete-alem", "Eti\u00f3p amete alem napt\u00e1r" },
         };
         return data;
